<template>
  <div>
    <div id="sidebar">
      <recent-violations :violations="violations" />
      <suggestion-counter :suggestions="suggestions"/>
      <div id="headlines">
        <headlines />
      </div>
      <action-buttons
        :has-swiper="hasSwiper"
        :shop="shop" />
    </div>
    <div
      id="accounting"
      class="clearfix">
      <div id="maincontent">
        <h1>Expenses</h1>
        <section>
          <table
            id="businessIncomeTable"
            class="business"><ul
              class="errors"
              style="display: none;"/>
            <thead>
              <tr>
                <th>To Shop</th>
                <th>Amount Due</th>
                <th>Payment Status</th>
              </tr>
            </thead>
            <tbody
              v-if="paymentObject.payments"
              style="display: table-row-group">
              <tr
                v-for="(payment, index) in paymentObject.payments"
                :key="index">
                <td>{{ payment.to }}</td>
                <td>
                  <span
                    v-if="payment.fake_paid === false"
                    class="amount">${{ (payment.amount).toFixed(2) }}</span>
                  <span
                    v-if="payment.fake_paid === true"
                    class="amount">$0.00
                  </span>
                </td>
                <td>
                  <span
                    v-if="payment.fake_paid === true"
                    class="amount">Paid</span>
                  <a
                    v-if="payment.fake_paid === false"
                    class="button paymentlink"
                    @click="togglePayment(payment)">Pay</a>
                </td>
              </tr>
            </tbody>
            <!-- <tfoot>
              <tr>
                <td>&nbsp;</td>
                <td><span class="totaltxt">Amount Outstanding</span></td>
                <td/>
                <td><span class="totaltxt">Total Paid</span></td>
              </tr>
              <tr class="lastrow">
                <td>Total</td>
                <td
                  v-if="paymentObject.outstanding"
                  id="outstanding">${{ paymentObject.outstanding.toFixed(2) }}</td>
                <td/>
                <td
                  v-if="paymentObject.paid"
                  id="received">${{ paymentObject.paid.toFixed(2) }}</td>
              </tr>
            </tfoot> -->
          </table>
        </section>
        <section>
          <div style="display: flex; justify-content: space-between; align-items: baseline;">
            <h1>Sales</h1>
            <p
              v-if="Object.keys(salesObject).length"
              style="font-size: 1.8em; !important"
              class="salesIncomeTotal">Total: ${{ salesObject.totalSales.toFixed(2) }}
            </p>
            <p
              v-else
              style="font-size: 1.8em; !important">Total: $0.00
            </p>
            <a
              class="button paymentlink"
              style="width: 102px; text-align: center;"
              @click="expandSales = !expandSales">
              <p
                v-if="expandSales"
                style="margin: 0;">Hide Sales
              </p>
              <p
                v-else
                style="margin: 0;">Show Sales
              </p>
            </a>
          </div>
          <table
            :class="{'closed':!expandSales}"
            class="sales">
            <thead v-if="expandSales === true">
              <tr>
                <th>Time</th>
                <th>From</th>
                <th>Account Number</th>
                <th>Amount</th>
                <th>Options</th>
              </tr>
            </thead>
            <tbody
              v-if="salesObject.sales && expandSales == true"
              style="display: table-row-group" >
              <tr
                v-for="(sale, index) in salesObject.sales"
                :key="index">
                <td>{{ moment.utc(sale.time).local().format('h:mm A') }}</td>
                <td>{{ sale.account_name }}</td>
                <td>{{ sale.from }}</td>
                <td>${{ sale.amount.toFixed(2) }}</td>
                <td><a
                  class="voidTransaction button"
                  @click="deleteSale(sale)" >VOID</a></td>
              </tr>
            </tbody>
            <!-- <tfoot>
              <tr class="lastrow">
                <td>Sales Total</td>
                <td
                  v-if="salesObject.totalSales"
                  class="salesIncomeTotal">${{ salesObject.totalSales.toFixed(2) }}</td>
                <td
                  v-else
                  class="salesIncomeTotal">$0.00</td>
                <td>&nbsp;</td>
                <td><a
                  class="expand"
                  @click="expandSales = !expandSales"><span class="arrow-down"/><span class="arrow-right"/></a></td>
              </tr>
            </tfoot> -->
          </table>
        </section>
        <!-- <h1>Total Income</h1>
        <table class="total">
          <tfoot>
            <tr class="lastrow">
              <td>Business Income + Sales Income</td> -->
        <!-- <td>&nbsp;</td>
              <td>&nbsp;</td> -->
        <!-- <td>
                <span
                  v-if="!Object.keys(salesObject).length && !Object.keys(paymentObject).length"
                  class="totalIncome">$0.00
                </span>
                <span
                  v-else-if="!Object.keys(salesObject).length && Object.keys(paymentObject).length"
                  class="totalIncome">${{ (paymentObject.received).toFixed(2) }}
                </span>
                <span
                  v-else-if="Object.keys(salesObject).length && !Object.keys(paymentObject).length"
                  class="totalIncome">${{ (salesObject.totalSales).toFixed(2) }}
                </span>
                <span
                  v-else
                  class="totalIncome">${{ (paymentObject.received + salesObject.totalSales).toFixed(2) }}
                </span>
              </td>
            </tr>
          </tfoot>
        </table> -->
      </div>
    </div>
  </div>
</template>

<script>
import RecentViolations from "./components/RecentViolation.vue";
import SuggestionCounter from "./components/SuggestionCounter.vue";
import Headlines from "../Headlines.vue";
import ActionButtons from "../ActionButtons.vue";

export default {
  components: {
    RecentViolations,
    SuggestionCounter,
    Headlines,
    ActionButtons,
  },
  props: {
    suggestions: Array,
    violations: Array,
    shop: Object,
    hasSwiper: Boolean,
  },
  data() {
    return{
      paymentObject:Object,
      salesObject:Object,
      expandSales:false,
      intervalID: ""
    };
  },
  created: function() {
    this.getPaymentData();
    this.getSalesData();
    this.poller();
  },
  destroyed: function() {
    clearInterval(this.intervalID);
  },
  methods : {
    getPaymentData() {
      app.api.Get( "/shop_payment/getPaymentsByShopType/" + this.shop.canonical_name).then( response => {
        this.paymentObject = response;
      }
    );},
  togglePayment(payment) {
    app.api.Put( "/shop_payment/toggleByShopPayment/" + payment.id).then( response => {
      this.getPaymentData();
    });
    },
  getSalesData() {
      app.api.Get( "/transaction/getSalesByShop/" + this.shop.canonical_name).then( response => {
        this.salesObject = response;
      });
    },
    deleteSale(sale){
        var result = confirm( "Void payment?" );
        if(result){
          app.api.Delete( "/transaction/" + sale.id).then( response => {
            this.getSalesData();
        });
      }
    },
    poller() {
      this.intervalID = setInterval(() => {
        this.getSalesData();
      }, 10000);
    }
  }
};
</script>

